Enum Inventory
pub enum Inventory {
Error,
Transaction(Txid),
Block(BlockHash),
CompactBlock(BlockHash),
WTx(Wtxid),
WitnessTransaction(Txid),
WitnessBlock(BlockHash),
Unknown {
inv_type: u32,
hash: [u8; 32],
},
}Expand description
An inventory item.
Variants
Error
Error — these inventories can be ignored.
This variant is never produced by decoding. Use is_error()
instead to check if a decoded item represents an error.
When deserializing type 0 inventory items from the wire, they are decoded as
Unknown { inv_type: 0, .. } instead. This variant exists for backwards
compatibility in case calling code constructs it directly (e.g.,
NetworkMessage::Inv(vec![Inventory::Error])).
Transaction(Txid)
Transaction
Block(BlockHash)
Block
CompactBlock(BlockHash)
Compact Block
WTx(Wtxid)
Witness Transaction by Wtxid
WitnessTransaction(Txid)
Witness Transaction
WitnessBlock(BlockHash)
Witness Block
Unknown
Unknown inventory type
Implementations